<?php

defined('_JEXEC') or die('Restricted index access');
jimport('joomla.plugin.plugin');

/**
 * This Joomla plugin 'ResponsiveMedia' helps add rich embedded third-party media into 
 * Joomla articles. All media that is added through this plugin is ready for the
 * responsive web.
 * 
 * The CSS and HTML are based on research and work by Theirry Koblentz, 
 * Anders Andersen and Niklaus Gerber. Their work was kindly documented by Jeff Hobbs 
 * at https://embedresponsively.com/.
 * 
 * @author Geoffrey Hayward - https://www.geoffhayward.eu
 * 
 * @copyright (c) 2013, Geoffrey Hayward
 * @version 1.5.0 (free)
 * @license GNU General Public License version 2 or later; see LICENSE.txt
 */
class plgContentResponsiveMedia extends JPlugin { 

    public function onContentPrepare($context, $row, &$params, $page = 0){    
        if(preg_match_all('/{embed:(.*?):(.*?)}/', $row->text, $matches)){
            for($index = 0; $index < sizeof($matches[1]); $index++){
                if(method_exists($this, $matches[1][$index])){
                    $row->text = preg_replace(
                        '/{embed:' . $matches[1][$index] . ':' . $matches[2][$index] . '}/',
                        $this->{$matches[1][$index]}($matches[2][$index]),
                        $row->text
                    );
                }
            }
            $doc = JFactory::getDocument();
            $doc->addStyleSheet('media/plg_content_responsivemedia/responsive-media.css');
        }
    }
    
    private function dailymotion($item) {
        return $this->credit("<div class=\"dailymotion-container\"><iframe src=\"https://www.dailymotion.com/embed/video/" . $item . "\" frameborder=\"0\" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe></div>");
    }

    private function instagram($item) {
        return $this->credit("<div class=\"instagram-container\"><iframe src=\"https://instagram.com/p/" . $item . "/embed/\" frameborder=\"0\" scrolling=\"no\" allowtransparency=\"true\"></iframe></div>");
    }

    private function youtube($item) {
        return $this->credit("<div class=\"youtube-container\"><iframe src=\"https://www.youtube.com/embed/" . $item . "\" frameborder=\"0\" allowfullscreen></iframe></div>");
    }

    private function vimeo($item) {
        return $this->credit("<div class=\"vimeo-container\"><iframe src=\"https://player.vimeo.com/video/" . $item . "\" frameborder=\"0\" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe></div>");
    }

    private function vine($item) {
        return $this->credit("<div class=\"vine-container\"><iframe width=\"100%\" src=\"https://vine.co/v/" . $item . "/embed/simple\" frameborder=\"0\" scrolling=\"no\" allowtransparency=\"true\"></iframe><script async src=\"//platform.vine.co/static/scripts/embed.js\" charset=\"utf-8\"></script></div>");
    }

    /**
     * The basic (free) version requires an author's credit. 
     *   
     * The paid version is available at https://www.geoffhayward.eu/software/joomla-responsive-media
     */
    private function credit($iframe) {
        //Load the language values for JText key.
        $this->loadLanguage();
        return "<div class=\"responsive-media-credit\">".$iframe."<p>".JText::_("PLG_CONTENT_RESPONSIVEMEDIA_CREDIT_TEXT")."</p></div>";
    }

}
